from pydantic.dataclasses import dataclass

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Sep:
    class Meta:
        name = "sep"
        namespace = "http://www.w3.org/1998/Math/MathML"
