from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MlabeledtrRowalign(Enum):
    TOP = "top"
    BOTTOM = "bottom"
    CENTER = "center"
    BASELINE = "baseline"
    AXIS = "axis"
