from enum import Enum


class UrlLang(Enum):
    AF = "AF"
    AR = "AR"
    AZ = "AZ"
    BG = "BG"
    CS = "CS"
    DA = "DA"
    DE = "DE"
    EN = "EN"
    EL = "EL"
    ES = "ES"
    FA = "FA"
    FI = "FI"
    FR = "FR"
    HE = "HE"
    HU = "HU"
    HY = "HY"
    IN = "IN"
    IS = "IS"
    IT = "IT"
    IW = "IW"
    JA = "JA"
    KA = "KA"
    KO = "KO"
    LT = "LT"
    MK = "MK"
    ML = "ML"
    NL = "NL"
    NO = "NO"
    PL = "PL"
    PT = "PT"
    PS = "PS"
    RO = "RO"
    RU = "RU"
    SL = "SL"
    SK = "SK"
    SQ = "SQ"
    SR = "SR"
    SV = "SV"
    SW = "SW"
    TH = "TH"
    TR = "TR"
    UK = "UK"
    VI = "VI"
    ZH = "ZH"
