from enum import Enum


class OtherIdSource(Enum):
    NASA = "NASA"
    KIE = "KIE"
    PIP = "PIP"
    POP = "POP"
    ARPL = "ARPL"
    CPC = "CPC"
    IND = "IND"
    CPFH = "CPFH"
    CLML = "CLML"
    NRCBL = "NRCBL"
    NLM = "NLM"
    QCIM = "QCIM"
