from enum import Enum


class LocationLabelType(Enum):
    PART = "part"
    CHAPTER = "chapter"
    SECTION = "section"
    APPENDIX = "appendix"
    FIGURE = "figure"
    TABLE = "table"
    BOX = "box"
