from enum import Enum


class OtherAbstractType(Enum):
    AAMC = "AAMC"
    AIDS = "AIDS"
    KIE = "KIE"
    PIP = "PIP"
    NASA = "NASA"
    PUBLISHER = "Publisher"
    PLAIN_LANGUAGE_SUMMARY = "plain-language-summary"
