from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MstyleLongdivstyle(Enum):
    LEFTTOP = "lefttop"
    STACKEDRIGHTRIGHT = "stackedrightright"
    MEDIUMSTACKEDRIGHTRIGHT = "mediumstackedrightright"
    SHORTSTACKEDRIGHTRIGHT = "shortstackedrightright"
    RIGHTTOP = "righttop"
    LEFT_RIGHT = "left/\right"
    LEFT_RIGHT_1 = "left)(right"
    RIGHT_RIGHT = ":right=right"
    STACKEDLEFTLEFT = "stackedleftleft"
    STACKEDLEFTLINETOP = "stackedleftlinetop"
