from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MoIndentalignfirst(Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"
    AUTO = "auto"
    ID = "id"
    INDENTALIGN = "indentalign"
