from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MstyleLocation(Enum):
    W = "w"
    NW = "nw"
    N = "n"
    NE = "ne"
    E = "e"
    SE = "se"
    S = "s"
    SW = "sw"
