from enum import Enum

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


class MaligngroupGroupalign(Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"
    DECIMALPOINT = "decimalpoint"
