from dataclasses import field
from decimal import Decimal
from pydantic.dataclasses import dataclass
from typing import Dict, List, Optional, Type, Union
from .abs import Abs
from .and_mod import And
from .annotation import Annotation
from .approx import Approx
from .arccos import Arccos
from .arccosh import Arccosh
from .arccot import Arccot
from .arccoth import Arccoth
from .arccsc import Arccsc
from .arccsch import Arccsch
from .arcsec import Arcsec
from .arcsech import Arcsech
from .arcsin import Arcsin
from .arcsinh import Arcsinh
from .arctan import Arctan
from .arctanh import Arctanh
from .arg import Arg
from .card import Card
from .cartesianproduct import Cartesianproduct
from .cbytes import Cbytes
from .ceiling import Ceiling
from .codomain import Codomain
from .columnalignstyle import Columnalignstyle
from .complexes import Complexes
from .compose import Compose
from .conjugate import Conjugate
from .cos import Cos
from .cosh import Cosh
from .cot import Cot
from .coth import Coth
from .cs import Cs
from .csc import Csc
from .csch import Csch
from .curl import Curl
from .declare_occurrence import DeclareOccurrence
from .determinant import Determinant
from .diff import Diff
from .divergence import Divergence
from .divide import Divide
from .domain import Domain
from .emptyset import Emptyset
from .eq import Eq
from .equivalent import Equivalent
from .eulergamma import Eulergamma
from .exists import Exists
from .exp import Exp
from .exponentiale import Exponentiale
from .factorial import Factorial
from .factorof import Factorof
from .false import FalseType
from .floor import Floor
from .forall import Forall
from .gcd import Gcd
from .geq import Geq
from .grad import Grad
from .gt import Gt
from .ident import Ident
from .image import Image
from .imaginary import Imaginary
from .imaginaryi import Imaginaryi
from .implies import Implies
from .in_mod import In
from .infinity import Infinity
from .int_mod import Int
from .integers import Integers
from .intersect import Intersect
from .interval import Interval
from .inverse import Inverse
from .lambda_mod import Lambda
from .laplacian import Laplacian
from .lcm import Lcm
from .leq import Leq
from .limit import Limit
from .linestyle import Linestyle
from .list_order import ListOrder
from .ln import Ln
from .log import Log
from .lt import Lt
from .maction_value import MactionValue
from .maligngroup import Maligngroup
from .malignmark import Malignmark
from .matrix import Matrix
from .matrixrow import Matrixrow
from .max import Max
from .mean import Mean
from .median import Median
from .menclose_value import MencloseValue
from .merror_value import MerrorValue
from .mfenced_value import MfencedValue
from .mfrac_bevelled import MfracBevelled
from .mfrac_denomalign import MfracDenomalign
from .mfrac_numalign import MfracNumalign
from .mfrac_value import MfracValue
from .mglyph import Mglyph
from .mi import Mi
from .min import Min
from .minus import Minus
from .mlongdiv_longdivstyle import MlongdivLongdivstyle
from .mlongdiv_value import MlongdivValue
from .mmultiscripts_value import MmultiscriptsValue
from .mn import Mn
from .mo import Mo
from .mode import Mode
from .moment import Moment
from .mover_accent import MoverAccent
from .mover_align import MoverAlign
from .mover_value import MoverValue
from .mpadded_value import MpaddedValue
from .mphantom_value import MphantomValue
from .mprescripts import Mprescripts
from .mroot_value import MrootValue
from .mrow_dir import MrowDir
from .mrow_value import MrowValue
from .ms import Ms
from .mscarries_location import MscarriesLocation
from .mscarries_value import MscarriesValue
from .mscarry_location import MscarryLocation
from .mscarry_value import MscarryValue
from .msgroup_value import MsgroupValue
from .msline import Msline
from .mspace import Mspace
from .msqrt_value import MsqrtValue
from .msrow_value import MsrowValue
from .mstack_charalign import MstackCharalign
from .mstack_stackalign import MstackStackalign
from .mstack_value import MstackValue
from .mstyle_accent import MstyleAccent
from .mstyle_accentunder import MstyleAccentunder
from .mstyle_align import MstyleAlign
from .mstyle_bevelled import MstyleBevelled
from .mstyle_charalign import MstyleCharalign
from .mstyle_denomalign import MstyleDenomalign
from .mstyle_dir import MstyleDir
from .mstyle_displaystyle import MstyleDisplaystyle
from .mstyle_edge import MstyleEdge
from .mstyle_equalcolumns import MstyleEqualcolumns
from .mstyle_equalrows import MstyleEqualrows
from .mstyle_fence import MstyleFence
from .mstyle_fontstyle import MstyleFontstyle
from .mstyle_fontweight import MstyleFontweight
from .mstyle_form import MstyleForm
from .mstyle_indentalign import MstyleIndentalign
from .mstyle_indentalignfirst import MstyleIndentalignfirst
from .mstyle_indentalignlast import MstyleIndentalignlast
from .mstyle_infixlinebreakstyle import MstyleInfixlinebreakstyle
from .mstyle_largeop import MstyleLargeop
from .mstyle_linebreak import MstyleLinebreak
from .mstyle_linebreakstyle import MstyleLinebreakstyle
from .mstyle_location import MstyleLocation
from .mstyle_longdivstyle import MstyleLongdivstyle
from .mstyle_mathvariant import MstyleMathvariant
from .mstyle_movablelimits import MstyleMovablelimits
from .mstyle_numalign import MstyleNumalign
from .mstyle_separator import MstyleSeparator
from .mstyle_side import MstyleSide
from .mstyle_stackalign import MstyleStackalign
from .mstyle_stretchy import MstyleStretchy
from .mstyle_symmetric import MstyleSymmetric
from .mstyle_value import MstyleValue
from .msub_value import MsubValue
from .msubsup_value import MsubsupValue
from .msup_value import MsupValue
from .mtable import Mtable
from .mtext import Mtext
from .munder_accentunder import MunderAccentunder
from .munder_align import MunderAlign
from .munder_value import MunderValue
from .munderover_accent import MunderoverAccent
from .munderover_accentunder import MunderoverAccentunder
from .munderover_align import MunderoverAlign
from .munderover_value import MunderoverValue
from .naturalnumbers import Naturalnumbers
from .neq import Neq
from .none import NoneType
from .not_mod import Not
from .notanumber import Notanumber
from .notin import Notin
from .notprsubset import Notprsubset
from .notsubset import Notsubset
from .or_mod import Or
from .outerproduct import Outerproduct
from .partialdiff import Partialdiff
from .pi import Pi
from .plus import Plus
from .power import Power
from .primes import Primes
from .product import Product
from .prsubset import Prsubset
from .quotient import Quotient
from .rationals import Rationals
from .real import Real
from .reals import Reals
from .rem import Rem
from .root import Root
from .scalarproduct import Scalarproduct
from .sdev import Sdev
from .sec import Sec
from .sech import Sech
from .selector import Selector
from .sep import Sep
from .setdiff import Setdiff
from .share import Share
from .sin import Sin
from .sinh import Sinh
from .subset import Subset
from .sum import Sum
from .tan import Tan
from .tanh import Tanh
from .tendsto import Tendsto
from .times import Times
from .transpose import Transpose
from .true import TrueType
from .union import UnionType
from .variance import Variance
from .vector import Vector
from .vectorproduct import Vectorproduct
from .verticalalign import Verticalalign
from .xor import Xor

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Condition:
    class Meta:
        name = "condition"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional["Ci"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional["Csymbol"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional["Cerror"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional["Piecewise"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional["Declare"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional["Fn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional["Reln"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional["ListType"] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional["Set"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class Lowlimit:
    class Meta:
        name = "lowlimit"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional["Ci"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional["Csymbol"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional["Cerror"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional["Piecewise"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional["Declare"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional["Fn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional["Reln"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional["ListType"] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional["Set"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class Uplimit:
    class Meta:
        name = "uplimit"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional["Ci"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional["Csymbol"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional["Cerror"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional["Piecewise"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional["Declare"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional["Fn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional["Reln"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional["ListType"] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional["Set"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class Set:
    class Meta:
        name = "set"
        namespace = "http://www.w3.org/1998/Math/MathML"

    bvar: List["Bvar"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domainofapplication: List["Domainofapplication"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    condition: List[Condition] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lowlimit: List[Lowlimit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    uplimit: List[Uplimit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List["ListType"] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List["Set"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )
    type: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )


@dataclass
class Domainofapplication:
    class Meta:
        name = "domainofapplication"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional["Ci"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional["Csymbol"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional["Cerror"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional["Piecewise"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional["Declare"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional["Fn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional["Reln"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional["ListType"] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional[Set] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class ListType:
    class Meta:
        name = "list"
        namespace = "http://www.w3.org/1998/Math/MathML"

    bvar: List["Bvar"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domainofapplication: List[Domainofapplication] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    condition: List[Condition] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lowlimit: List[Lowlimit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    uplimit: List[Uplimit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List["ListType"] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )
    order: Optional[ListOrder] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )


@dataclass
class Degree:
    class Meta:
        name = "degree"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional["Ci"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional["Csymbol"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional["Cerror"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional["Piecewise"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional["Declare"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional["Fn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional["Reln"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional[ListType] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional[Set] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class Mrow:
    class Meta:
        name = "mrow"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List["Munder"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List["Msubsup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List["Msup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List["Msub"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List["Mfenced"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List["Mroot"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List["Mfrac"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List["Mrow"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Mrow.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MrowValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    dir: Optional[MrowDir] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional["Munder"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional["Msubsup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional["Msup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional["Msub"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional["Mfenced"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional["Mroot"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional["Mfrac"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional["Mrow"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mrow.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Reln:
    class Meta:
        name = "reln"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class Fn:
    class Meta:
        name = "fn"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional["Ci"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional["Csymbol"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional["Cerror"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional["Piecewise"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional["Declare"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional["Fn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional[Reln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional[ListType] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional[Set] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class Mfrac:
    class Meta:
        name = "mfrac"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munder: List["Munder"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msubsup: List["Msubsup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msup: List["Msup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msub: List["Msub"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfenced: List["Mfenced"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mroot: List["Mroot"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfrac: List["Mfrac"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    semantics: List["Mfrac.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MfracValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    linethickness: Optional[Union[str, MfracValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    numalign: Optional[MfracNumalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    denomalign: Optional[MfracDenomalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    bevelled: Optional[MfracBevelled] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional["Munder"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional["Msubsup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional["Msup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional["Msub"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional["Mfenced"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional["Mroot"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional["Mfrac"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mfrac.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Declare:
    class Meta:
        name = "declare"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    type: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    scope: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    nargs: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    occurrence: Optional[DeclareOccurrence] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )


@dataclass
class Mroot:
    class Meta:
        name = "mroot"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munder: List["Munder"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msubsup: List["Msubsup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msup: List["Msup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msub: List["Msub"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfenced: List["Mfenced"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mroot: List["Mroot"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    semantics: List["Mroot.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MrootValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional["Munder"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional["Msubsup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional["Msup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional["Msub"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional["Mfenced"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional["Mroot"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mroot.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Mfenced:
    class Meta:
        name = "mfenced"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List["Munder"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List["Msubsup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List["Msup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List["Msub"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List["Mfenced"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Mfenced.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MfencedValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    open: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    close: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    separators: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional["Munder"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional["Msubsup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional["Msup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional["Msub"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional["Mfenced"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mfenced.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Otherwise:
    class Meta:
        name = "otherwise"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional["Ci"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional["Csymbol"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional["Cerror"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional["Piecewise"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional[Declare] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional[Fn] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional[Reln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional[ListType] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional[Set] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )


@dataclass
class Piece:
    class Meta:
        name = "piece"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )


@dataclass
class Msub:
    class Meta:
        name = "msub"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munder: List["Munder"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msubsup: List["Msubsup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msup: List["Msup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msub: List["Msub"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    semantics: List["Msub.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MsubValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    subscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional["Munder"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional["Msubsup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional["Msup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional["Msub"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Msub.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Piecewise:
    class Meta:
        name = "piecewise"
        namespace = "http://www.w3.org/1998/Math/MathML"

    piece: List[Piece] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    otherwise: List[Otherwise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )


@dataclass
class Cerror:
    class Meta:
        name = "cerror"
        namespace = "http://www.w3.org/1998/Math/MathML"

    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "min_occurs": 1,
        }
    )
    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )


@dataclass
class Msup:
    class Meta:
        name = "msup"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munder: List["Munder"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msubsup: List["Msubsup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msup: List["Msup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    semantics: List["Msup.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MsupValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    superscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional["Munder"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional["Msubsup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional["Msup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Msup.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Msubsup:
    class Meta:
        name = "msubsup"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    munder: List["Munder"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    msubsup: List["Msubsup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    semantics: List["Msubsup.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MsubsupValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    subscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    superscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional["Munder"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional["Msubsup"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Msubsup.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Munder:
    class Meta:
        name = "munder"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munder: List["Munder"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    semantics: List["Munder.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MunderValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    accentunder: Optional[MunderAccentunder] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    align: Optional[MunderAlign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional["Munder"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Munder.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Mover:
    class Meta:
        name = "mover"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mover: List["Mover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    semantics: List["Mover.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 2,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MoverValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    accent: Optional[MoverAccent] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    align: Optional[MoverAlign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional["Mover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mover.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Munderover:
    class Meta:
        name = "munderover"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    munderover: List["Munderover"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    semantics: List["Munderover.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "max_occurs": 3,
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MunderoverValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    accent: Optional[MunderoverAccent] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    accentunder: Optional[MunderoverAccentunder] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    align: Optional[MunderoverAlign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional["Munderover"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Munderover.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Mmultiscripts:
    class Meta:
        name = "mmultiscripts"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List["Mmultiscripts"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Mmultiscripts.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    none: List[NoneType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mprescripts: Optional[Mprescripts] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MmultiscriptsValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    subscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    superscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional["Mmultiscripts"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mmultiscripts.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class ImpliedMrow:
    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mtable: List["Mtable"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    menclose: List["Menclose"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mphantom: List["Mphantom"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mpadded: List["Mpadded"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    merror: List["Merror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mstyle: List["Mstyle"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    msqrt: List["Msqrt"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    semantics: List["ImpliedMrow.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mtable: Optional["Mtable"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        menclose: Optional["Menclose"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mphantom: Optional["Mphantom"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mpadded: Optional["Mpadded"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        merror: Optional["Merror"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mstyle: Optional["Mstyle"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        msqrt: Optional["Msqrt"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        semantics: Optional["ImpliedMrow.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Menclose(ImpliedMrow):
    class Meta:
        name = "menclose"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MencloseValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    notation: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )


@dataclass
class Merror(ImpliedMrow):
    class Meta:
        name = "merror"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MerrorValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )


@dataclass
class Mpadded(ImpliedMrow):
    class Meta:
        name = "mpadded"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MpaddedValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    height: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*([\+\-]?[0-9]*(\.[0-9]*)?\s*((%?\s*(height|depth|width)?)|e[mx]|in|cm|mm|p[xtc]|((negative)?((very){0,2}thi(n|ck)|medium)mathspace)))\s*",
        }
    )
    depth: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*([\+\-]?[0-9]*(\.[0-9]*)?\s*((%?\s*(height|depth|width)?)|e[mx]|in|cm|mm|p[xtc]|((negative)?((very){0,2}thi(n|ck)|medium)mathspace)))\s*",
        }
    )
    width: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*([\+\-]?[0-9]*(\.[0-9]*)?\s*((%?\s*(height|depth|width)?)|e[mx]|in|cm|mm|p[xtc]|((negative)?((very){0,2}thi(n|ck)|medium)mathspace)))\s*",
        }
    )
    lspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*([\+\-]?[0-9]*(\.[0-9]*)?\s*((%?\s*(height|depth|width)?)|e[mx]|in|cm|mm|p[xtc]|((negative)?((very){0,2}thi(n|ck)|medium)mathspace)))\s*",
        }
    )
    voffset: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*([\+\-]?[0-9]*(\.[0-9]*)?\s*((%?\s*(height|depth|width)?)|e[mx]|in|cm|mm|p[xtc]|((negative)?((very){0,2}thi(n|ck)|medium)mathspace)))\s*",
        }
    )


@dataclass
class Mphantom(ImpliedMrow):
    class Meta:
        name = "mphantom"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MphantomValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )


@dataclass
class Msqrt(ImpliedMrow):
    class Meta:
        name = "msqrt"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MsqrtValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )


@dataclass
class Mstyle(ImpliedMrow):
    class Meta:
        name = "mstyle"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    scriptlevel: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    displaystyle: Optional[MstyleDisplaystyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    scriptsizemultiplier: Optional[Decimal] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    scriptminsize: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    infixlinebreakstyle: Optional[MstyleInfixlinebreakstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    decimalpoint: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*\S\s*",
        }
    )
    accent: Optional[MstyleAccent] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    accentunder: Optional[MstyleAccentunder] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    align: Optional[MstyleAlign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    alignmentscope: List[MstyleValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    bevelled: Optional[MstyleBevelled] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    charalign: Optional[MstyleCharalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    charspacing: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    close: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    columnalign: List[Columnalignstyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    columnlines: List[Linestyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    columnspacing: List[str] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
            "tokens": True,
        }
    )
    columnspan: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    columnwidth: List[MstyleValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    crossout: List[MstyleValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    denomalign: Optional[MstyleDenomalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    depth: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    dir: Optional[MstyleDir] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    edge: Optional[MstyleEdge] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    equalcolumns: Optional[MstyleEqualcolumns] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    equalrows: Optional[MstyleEqualrows] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fence: Optional[MstyleFence] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    form: Optional[MstyleForm] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    frame: Optional[Linestyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    framespacing: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "length": 2,
            "tokens": True,
        }
    )
    groupalign: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"(\s*\{\s*(left|center|right|decimalpoint)(\s+(left|center|right|decimalpoint))*\})*\s*",
        }
    )
    height: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    indentalign: Optional[MstyleIndentalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    indentalignfirst: Optional[MstyleIndentalignfirst] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    indentalignlast: Optional[MstyleIndentalignlast] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    indentshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    indentshiftfirst: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    indentshiftlast: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    indenttarget: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    largeop: Optional[MstyleLargeop] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    leftoverhang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    length: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    linebreak: Optional[MstyleLinebreak] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    linebreakmultchar: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    linebreakstyle: Optional[MstyleLinebreakstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    lineleading: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    linethickness: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    location: Optional[MstyleLocation] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    longdivstyle: Optional[MstyleLongdivstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    lquote: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    lspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    mathsize: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    mathvariant: Optional[MstyleMathvariant] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    maxsize: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    minlabelspacing: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    minsize: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    movablelimits: Optional[MstyleMovablelimits] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    mslinethickness: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    notation: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    numalign: Optional[MstyleNumalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    open: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    position: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    rightoverhang: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    rowalign: List[Verticalalign] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    rowlines: List[Linestyle] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    rowspacing: List[str] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
            "tokens": True,
        }
    )
    rowspan: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    rquote: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    rspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    selection: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    separator: Optional[MstyleSeparator] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    separators: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    shift: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    side: Optional[MstyleSide] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    stackalign: Optional[MstyleStackalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    stretchy: Optional[MstyleStretchy] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    subscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    superscriptshift: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    symmetric: Optional[MstyleSymmetric] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    valign: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    width: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    fontfamily: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fontweight: Optional[MstyleFontweight] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fontstyle: Optional[MstyleFontstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    fontsize: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    color: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    background: Optional[Union[str, MstyleValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    veryverythinmathspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    verythinmathspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    thinmathspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    mediummathspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    thickmathspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    verythickmathspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )
    veryverythickmathspace: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )


@dataclass
class AnnotationXmlModel:
    class Meta:
        name = "annotation-xml.model"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cerror: List["Cerror"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    piecewise: List["Piecewise"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    declare: List["Declare"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    fn: List["Fn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    reln: List["Reln"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    semantics: List["AnnotationXmlModel.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    other_element: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##other",
        }
    )
    local_element: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##local",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cerror: Optional["Cerror"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        piecewise: Optional["Piecewise"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        declare: Optional["Declare"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        fn: Optional["Fn"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        reln: Optional["Reln"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        semantics: Optional["AnnotationXmlModel.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        annotation_xml: List["AnnotationXml"] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
                "namespace": "http://www.w3.org/1998/Math/MathML",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class AnnotationXml(AnnotationXmlModel):
    class Meta:
        name = "annotation-xml"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    cd: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    name: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )
    src: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )


@dataclass
class Bvar:
    class Meta:
        name = "bvar"
        namespace = "http://www.w3.org/1998/Math/MathML"

    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Bvar.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    degree: List[Degree] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )

    @dataclass
    class Semantics:
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Bvar.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Mscarry:
    class Meta:
        name = "mscarry"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Mscarry.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    none: List[NoneType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MscarryValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    location: Optional[MscarryLocation] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    crossout: List[MscarryValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional[Cerror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional[Piecewise] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional[Declare] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional[Fn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional[Reln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mscarry.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Msrow:
    class Meta:
        name = "msrow"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Msrow.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    none: List[NoneType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MsrowValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    position: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional[Cerror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional[Piecewise] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional[Declare] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional[Fn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional[Reln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Msrow.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Mscarries:
    class Meta:
        name = "mscarries"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Mscarries.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    none: List[NoneType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mscarry: List[Mscarry] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MscarriesValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    position: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    location: Optional[MscarriesLocation] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    crossout: List[MscarriesValue] = field(
        default_factory=list,
        metadata={
            "type": "Attribute",
            "tokens": True,
        }
    )
    scriptsizemultiplier: Optional[Decimal] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional[Cerror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional[Piecewise] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional[Declare] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional[Fn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional[Reln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mscarries.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Msgroup:
    class Meta:
        name = "msgroup"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Msgroup.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mscarries: List[Mscarries] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msline: List[Msline] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msrow: List[Msrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msgroup: List["Msgroup"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MsgroupValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    position: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    shift: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional[Cerror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional[Piecewise] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional[Declare] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional[Fn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional[Reln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Msgroup.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class Mstack:
    class Meta:
        name = "mstack"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List["Csymbol"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List["Mstack"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Mstack.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mscarries: List[Mscarries] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msline: List[Msline] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msrow: List[Msrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msgroup: List[Msgroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MstackValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    align: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*(top|bottom|center|baseline|axis)\s*[0-9]*",
        }
    )
    stackalign: Optional[MstackStackalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    charalign: Optional[MstackCharalign] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    charspacing: Optional[Union[str, MstackValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((-?[0-9]*(\.[0-9]*)?(e[mx]|in|cm|mm|p[xtc]|%)?)|(negative)?((very){0,2}thi(n|ck)|medium)mathspace)\s*",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional["Csymbol"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional[Cerror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional[Piecewise] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional[Declare] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional[Fn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional[Reln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional["Mstack"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mstack.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class CsymbolContent:
    class Meta:
        name = "csymbol.content"

    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
            "choices": (
                {
                    "name": "mglyph",
                    "type": Mglyph,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "maction",
                    "type": Type["Maction"],
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mlongdiv",
                    "type": Type["Mlongdiv"],
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mstack",
                    "type": Mstack,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mtable",
                    "type": Mtable,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mmultiscripts",
                    "type": Mmultiscripts,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "munderover",
                    "type": Munderover,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mover",
                    "type": Mover,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "munder",
                    "type": Munder,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msubsup",
                    "type": Msubsup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msup",
                    "type": Msup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msub",
                    "type": Msub,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "menclose",
                    "type": Menclose,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mfenced",
                    "type": Mfenced,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mphantom",
                    "type": Mphantom,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mpadded",
                    "type": Mpadded,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "merror",
                    "type": Merror,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mstyle",
                    "type": Mstyle,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mroot",
                    "type": Mroot,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msqrt",
                    "type": Msqrt,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mfrac",
                    "type": Mfrac,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mrow",
                    "type": Mrow,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "maligngroup",
                    "type": Maligngroup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "malignmark",
                    "type": Malignmark,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "ms",
                    "type": Ms,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mspace",
                    "type": Mspace,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mtext",
                    "type": Mtext,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mo",
                    "type": Mo,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mn",
                    "type": Mn,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mi",
                    "type": Mi,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
            ),
        }
    )


@dataclass
class Csymbol(CsymbolContent):
    class Meta:
        name = "csymbol"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )
    type: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    cd: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )


@dataclass
class Mlongdiv:
    class Meta:
        name = "mlongdiv"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    ci: List["Ci"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    csymbol: List[Csymbol] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "sequence": 1,
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "sequence": 1,
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "sequence": 1,
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "sequence": 1,
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "sequence": 1,
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "sequence": 1,
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "sequence": 1,
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mlongdiv: List["Mlongdiv"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mstack: List[Mstack] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    semantics: List["Mlongdiv.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    mscarries: List[Mscarries] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    msline: List[Msline] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    msrow: List[Msrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    msgroup: List[Msgroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "sequence": 1,
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MlongdivValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    position: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    shift: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    longdivstyle: Optional[MlongdivLongdivstyle] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional["Apply"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional["Bind"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional["Ci"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional[Csymbol] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional[Cerror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional[Piecewise] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional[Declare] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional[Fn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional[Reln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional["Mlongdiv"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional[Mstack] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Mlongdiv.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class CiContent:
    class Meta:
        name = "ci.content"

    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
            "choices": (
                {
                    "name": "mglyph",
                    "type": Mglyph,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "maction",
                    "type": Type["Maction"],
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mlongdiv",
                    "type": Mlongdiv,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mstack",
                    "type": Mstack,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mtable",
                    "type": Mtable,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mmultiscripts",
                    "type": Mmultiscripts,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "munderover",
                    "type": Munderover,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mover",
                    "type": Mover,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "munder",
                    "type": Munder,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msubsup",
                    "type": Msubsup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msup",
                    "type": Msup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msub",
                    "type": Msub,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "menclose",
                    "type": Menclose,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mfenced",
                    "type": Mfenced,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mphantom",
                    "type": Mphantom,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mpadded",
                    "type": Mpadded,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "merror",
                    "type": Merror,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mstyle",
                    "type": Mstyle,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mroot",
                    "type": Mroot,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msqrt",
                    "type": Msqrt,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mfrac",
                    "type": Mfrac,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mrow",
                    "type": Mrow,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "maligngroup",
                    "type": Maligngroup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "malignmark",
                    "type": Malignmark,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "ms",
                    "type": Ms,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mspace",
                    "type": Mspace,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mtext",
                    "type": Mtext,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mo",
                    "type": Mo,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mn",
                    "type": Mn,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mi",
                    "type": Mi,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
            ),
        }
    )


@dataclass
class Ci(CiContent):
    class Meta:
        name = "ci"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )
    type: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )


@dataclass
class Logbase:
    class Meta:
        name = "logbase"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional[Ci] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional[Csymbol] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional[Cerror] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional[Piecewise] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional[Declare] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional[Fn] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional[Reln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional[ListType] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional[Set] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class Momentabout:
    class Meta:
        name = "momentabout"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: Optional["Apply"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    bind: Optional["Bind"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ci: Optional[Ci] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cn: Optional["Cn"] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csymbol: Optional[Csymbol] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cbytes: Optional[Cbytes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cerror: Optional[Cerror] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cs: Optional[Cs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    share: Optional[Share] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    piecewise: Optional[Piecewise] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    declare: Optional[Declare] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    fn: Optional[Fn] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reln: Optional[Reln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    interval: Optional[Interval] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    moment: Optional[Moment] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    log: Optional[Log] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ln: Optional[Ln] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    image: Optional[Image] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    codomain: Optional[Codomain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    domain: Optional[Domain] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ident: Optional[Ident] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    inverse: Optional[Inverse] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: Optional[Lambda] = field(
        default=None,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: Optional[Compose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    quotient: Optional[Quotient] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divide: Optional[Divide] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    minus: Optional[Minus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    power: Optional[Power] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rem: Optional[Rem] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    root: Optional[Root] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorial: Optional[Factorial] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    abs: Optional[Abs] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    conjugate: Optional[Conjugate] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arg: Optional[Arg] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    real: Optional[Real] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginary: Optional[Imaginary] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    floor: Optional[Floor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    ceiling: Optional[Ceiling] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exp: Optional[Exp] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    min: Optional[Min] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    max: Optional[Max] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lcm: Optional[Lcm] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gcd: Optional[Gcd] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    times: Optional[Times] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    plus: Optional[Plus] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    xor: Optional[Xor] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    or_value: Optional[Or] = field(
        default=None,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: Optional[And] = field(
        default=None,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: Optional[Not] = field(
        default=None,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: Optional[Equivalent] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    implies: Optional[Implies] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exists: Optional[Exists] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    forall: Optional[Forall] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    leq: Optional[Leq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    geq: Optional[Geq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    lt: Optional[Lt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    gt: Optional[Gt] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eq: Optional[Eq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tendsto: Optional[Tendsto] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    factorof: Optional[Factorof] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    approx: Optional[Approx] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    neq: Optional[Neq] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    int_value: Optional[Int] = field(
        default=None,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: Optional[Diff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: Optional[Partialdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    laplacian: Optional[Laplacian] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    curl: Optional[Curl] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    grad: Optional[Grad] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    divergence: Optional[Divergence] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    list_value: Optional[ListType] = field(
        default=None,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: Optional[Set] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: Optional[Cartesianproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    intersect: Optional[Intersect] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    union: Optional[UnionType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    setdiff: Optional[Setdiff] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: Optional[Notprsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notsubset: Optional[Notsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notin: Optional[Notin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    in_value: Optional[In] = field(
        default=None,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: Optional[Prsubset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    subset: Optional[Subset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    card: Optional[Card] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sum: Optional[Sum] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    product: Optional[Product] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    limit: Optional[Limit] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctanh: Optional[Arctanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: Optional[Arcsinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsech: Optional[Arcsech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsec: Optional[Arcsec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsch: Optional[Arccsch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccsc: Optional[Arccsc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccoth: Optional[Arccoth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccot: Optional[Arccot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccosh: Optional[Arccosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arctan: Optional[Arctan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arccos: Optional[Arccos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    arcsin: Optional[Arcsin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    coth: Optional[Coth] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csch: Optional[Csch] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sech: Optional[Sech] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tanh: Optional[Tanh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cosh: Optional[Cosh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sinh: Optional[Sinh] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cot: Optional[Cot] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    csc: Optional[Csc] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sec: Optional[Sec] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    tan: Optional[Tan] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    cos: Optional[Cos] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sin: Optional[Sin] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mode: Optional[Mode] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    median: Optional[Median] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    variance: Optional[Variance] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    sdev: Optional[Sdev] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    mean: Optional[Mean] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: Optional[Matrixrow] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    matrix: Optional[Matrix] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vector: Optional[Vector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    transpose: Optional[Transpose] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    determinant: Optional[Determinant] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    selector: Optional[Selector] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: Optional[Outerproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: Optional[Scalarproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: Optional[Vectorproduct] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    emptyset: Optional[Emptyset] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    primes: Optional[Primes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    complexes: Optional[Complexes] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: Optional[Naturalnumbers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    rationals: Optional[Rationals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    reals: Optional[Reals] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    integers: Optional[Integers] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    infinity: Optional[Infinity] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: Optional[Eulergamma] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    pi: Optional[Pi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    false: Optional[FalseType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    true: Optional[TrueType] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    notanumber: Optional[Notanumber] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: Optional[Imaginaryi] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: Optional[Exponentiale] = field(
        default=None,
        metadata={
            "type": "Element",
        }
    )


@dataclass
class ApplyContent:
    class Meta:
        name = "apply.content"

    apply: List["Apply"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    bind: List["Bind"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ci: List[Ci] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csymbol: List[Csymbol] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    bvar: List[Bvar] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    domainofapplication: List[Domainofapplication] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    condition: List[Condition] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    lowlimit: List[Lowlimit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    uplimit: List[Uplimit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    degree: List[Degree] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    momentabout: List[Momentabout] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )
    logbase: List[Logbase] = field(
        default_factory=list,
        metadata={
            "type": "Element",
            "namespace": "http://www.w3.org/1998/Math/MathML",
        }
    )


@dataclass
class Apply(ApplyContent):
    class Meta:
        name = "apply"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )


@dataclass
class BindContent(ApplyContent):
    class Meta:
        name = "bind.content"


@dataclass
class Bind(BindContent):
    class Meta:
        name = "bind"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )


@dataclass
class Maction:
    class Meta:
        name = "maction"
        namespace = "http://www.w3.org/1998/Math/MathML"

    apply: List[Apply] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    bind: List[Bind] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ci: List[Ci] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cn: List["Cn"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csymbol: List[Csymbol] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cbytes: List[Cbytes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cerror: List[Cerror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cs: List[Cs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    share: List[Share] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    piecewise: List[Piecewise] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    declare: List[Declare] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    fn: List[Fn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reln: List[Reln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    interval: List[Interval] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    moment: List[Moment] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    log: List[Log] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ln: List[Ln] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    image: List[Image] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    codomain: List[Codomain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    domain: List[Domain] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ident: List[Ident] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    inverse: List[Inverse] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lambda_value: List[Lambda] = field(
        default_factory=list,
        metadata={
            "name": "lambda",
            "type": "Element",
        }
    )
    compose: List[Compose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    quotient: List[Quotient] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divide: List[Divide] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    minus: List[Minus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    power: List[Power] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rem: List[Rem] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    root: List[Root] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorial: List[Factorial] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    abs: List[Abs] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    conjugate: List[Conjugate] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arg: List[Arg] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    real: List[Real] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginary: List[Imaginary] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    floor: List[Floor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ceiling: List[Ceiling] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exp: List[Exp] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    min: List[Min] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    max: List[Max] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lcm: List[Lcm] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gcd: List[Gcd] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    times: List[Times] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    plus: List[Plus] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    xor: List[Xor] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    or_value: List[Or] = field(
        default_factory=list,
        metadata={
            "name": "or",
            "type": "Element",
        }
    )
    and_value: List[And] = field(
        default_factory=list,
        metadata={
            "name": "and",
            "type": "Element",
        }
    )
    not_value: List[Not] = field(
        default_factory=list,
        metadata={
            "name": "not",
            "type": "Element",
        }
    )
    equivalent: List[Equivalent] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    implies: List[Implies] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exists: List[Exists] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    forall: List[Forall] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    leq: List[Leq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    geq: List[Geq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    lt: List[Lt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    gt: List[Gt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eq: List[Eq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tendsto: List[Tendsto] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    factorof: List[Factorof] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    approx: List[Approx] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    neq: List[Neq] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    int_value: List[Int] = field(
        default_factory=list,
        metadata={
            "name": "int",
            "type": "Element",
        }
    )
    diff: List[Diff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    partialdiff: List[Partialdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    laplacian: List[Laplacian] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    curl: List[Curl] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    grad: List[Grad] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    divergence: List[Divergence] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    list_value: List[ListType] = field(
        default_factory=list,
        metadata={
            "name": "list",
            "type": "Element",
        }
    )
    set: List[Set] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cartesianproduct: List[Cartesianproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    intersect: List[Intersect] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    union: List[UnionType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    setdiff: List[Setdiff] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notprsubset: List[Notprsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notsubset: List[Notsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notin: List[Notin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    in_value: List[In] = field(
        default_factory=list,
        metadata={
            "name": "in",
            "type": "Element",
        }
    )
    prsubset: List[Prsubset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    subset: List[Subset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    card: List[Card] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sum: List[Sum] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    product: List[Product] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    limit: List[Limit] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctanh: List[Arctanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsinh: List[Arcsinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsech: List[Arcsech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsec: List[Arcsec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsch: List[Arccsch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccsc: List[Arccsc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccoth: List[Arccoth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccot: List[Arccot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccosh: List[Arccosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arctan: List[Arctan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arccos: List[Arccos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    arcsin: List[Arcsin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    coth: List[Coth] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csch: List[Csch] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sech: List[Sech] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tanh: List[Tanh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cosh: List[Cosh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sinh: List[Sinh] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cot: List[Cot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    csc: List[Csc] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sec: List[Sec] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    tan: List[Tan] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    cos: List[Cos] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sin: List[Sin] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mode: List[Mode] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    median: List[Median] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    variance: List[Variance] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    sdev: List[Sdev] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mean: List[Mean] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrixrow: List[Matrixrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    matrix: List[Matrix] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vector: List[Vector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    transpose: List[Transpose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    determinant: List[Determinant] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    selector: List[Selector] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    outerproduct: List[Outerproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    scalarproduct: List[Scalarproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    vectorproduct: List[Vectorproduct] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    emptyset: List[Emptyset] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    primes: List[Primes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    complexes: List[Complexes] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    naturalnumbers: List[Naturalnumbers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    rationals: List[Rationals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    reals: List[Reals] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    integers: List[Integers] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    infinity: List[Infinity] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    eulergamma: List[Eulergamma] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    pi: List[Pi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    false: List[FalseType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    true: List[TrueType] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    notanumber: List[Notanumber] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    imaginaryi: List[Imaginaryi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    exponentiale: List[Exponentiale] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maction: List["Maction"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mlongdiv: List[Mlongdiv] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstack: List[Mstack] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtable: List[Mtable] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mmultiscripts: List[Mmultiscripts] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munderover: List[Munderover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mover: List[Mover] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    munder: List[Munder] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msubsup: List[Msubsup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msup: List[Msup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msub: List[Msub] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    menclose: List[Menclose] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfenced: List[Mfenced] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mphantom: List[Mphantom] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mpadded: List[Mpadded] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    merror: List[Merror] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mstyle: List[Mstyle] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mroot: List[Mroot] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    msqrt: List[Msqrt] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mfrac: List[Mfrac] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mrow: List[Mrow] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    maligngroup: List[Maligngroup] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    malignmark: List[Malignmark] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    ms: List[Ms] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mspace: List[Mspace] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mtext: List[Mtext] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mo: List[Mo] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mn: List[Mn] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    mi: List[Mi] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    semantics: List["Maction.Semantics"] = field(
        default_factory=list,
        metadata={
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MactionValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    actiontype: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    selection: Optional[int] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )

    @dataclass
    class Semantics:
        apply: Optional[Apply] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        bind: Optional[Bind] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ci: Optional[Ci] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cn: Optional["Cn"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csymbol: Optional[Csymbol] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cbytes: Optional[Cbytes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cerror: Optional[Cerror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cs: Optional[Cs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        share: Optional[Share] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        piecewise: Optional[Piecewise] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        declare: Optional[Declare] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        fn: Optional[Fn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reln: Optional[Reln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        interval: Optional[Interval] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        moment: Optional[Moment] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        log: Optional[Log] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ln: Optional[Ln] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        image: Optional[Image] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        codomain: Optional[Codomain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        domain: Optional[Domain] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ident: Optional[Ident] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        inverse: Optional[Inverse] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lambda_value: Optional[Lambda] = field(
            default=None,
            metadata={
                "name": "lambda",
                "type": "Element",
            }
        )
        compose: Optional[Compose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        quotient: Optional[Quotient] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divide: Optional[Divide] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        minus: Optional[Minus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        power: Optional[Power] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rem: Optional[Rem] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        root: Optional[Root] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorial: Optional[Factorial] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        abs: Optional[Abs] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        conjugate: Optional[Conjugate] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arg: Optional[Arg] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        real: Optional[Real] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginary: Optional[Imaginary] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        floor: Optional[Floor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ceiling: Optional[Ceiling] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exp: Optional[Exp] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        min: Optional[Min] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        max: Optional[Max] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lcm: Optional[Lcm] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gcd: Optional[Gcd] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        times: Optional[Times] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        plus: Optional[Plus] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        xor: Optional[Xor] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        or_value: Optional[Or] = field(
            default=None,
            metadata={
                "name": "or",
                "type": "Element",
            }
        )
        and_value: Optional[And] = field(
            default=None,
            metadata={
                "name": "and",
                "type": "Element",
            }
        )
        not_value: Optional[Not] = field(
            default=None,
            metadata={
                "name": "not",
                "type": "Element",
            }
        )
        equivalent: Optional[Equivalent] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        implies: Optional[Implies] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exists: Optional[Exists] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        forall: Optional[Forall] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        leq: Optional[Leq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        geq: Optional[Geq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        lt: Optional[Lt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        gt: Optional[Gt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eq: Optional[Eq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tendsto: Optional[Tendsto] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        factorof: Optional[Factorof] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        approx: Optional[Approx] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        neq: Optional[Neq] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        int_value: Optional[Int] = field(
            default=None,
            metadata={
                "name": "int",
                "type": "Element",
            }
        )
        diff: Optional[Diff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        partialdiff: Optional[Partialdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        laplacian: Optional[Laplacian] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        curl: Optional[Curl] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        grad: Optional[Grad] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        divergence: Optional[Divergence] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        list_value: Optional[ListType] = field(
            default=None,
            metadata={
                "name": "list",
                "type": "Element",
            }
        )
        set: Optional[Set] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cartesianproduct: Optional[Cartesianproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        intersect: Optional[Intersect] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        union: Optional[UnionType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        setdiff: Optional[Setdiff] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notprsubset: Optional[Notprsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notsubset: Optional[Notsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notin: Optional[Notin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        in_value: Optional[In] = field(
            default=None,
            metadata={
                "name": "in",
                "type": "Element",
            }
        )
        prsubset: Optional[Prsubset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        subset: Optional[Subset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        card: Optional[Card] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sum: Optional[Sum] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        product: Optional[Product] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        limit: Optional[Limit] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctanh: Optional[Arctanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsinh: Optional[Arcsinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsech: Optional[Arcsech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsec: Optional[Arcsec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsch: Optional[Arccsch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccsc: Optional[Arccsc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccoth: Optional[Arccoth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccot: Optional[Arccot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccosh: Optional[Arccosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arctan: Optional[Arctan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arccos: Optional[Arccos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        arcsin: Optional[Arcsin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        coth: Optional[Coth] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csch: Optional[Csch] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sech: Optional[Sech] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tanh: Optional[Tanh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cosh: Optional[Cosh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sinh: Optional[Sinh] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cot: Optional[Cot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        csc: Optional[Csc] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sec: Optional[Sec] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        tan: Optional[Tan] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        cos: Optional[Cos] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sin: Optional[Sin] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mode: Optional[Mode] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        median: Optional[Median] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        variance: Optional[Variance] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        sdev: Optional[Sdev] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mean: Optional[Mean] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrixrow: Optional[Matrixrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        matrix: Optional[Matrix] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vector: Optional[Vector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        transpose: Optional[Transpose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        determinant: Optional[Determinant] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        selector: Optional[Selector] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        outerproduct: Optional[Outerproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        scalarproduct: Optional[Scalarproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        vectorproduct: Optional[Vectorproduct] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        emptyset: Optional[Emptyset] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        primes: Optional[Primes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        complexes: Optional[Complexes] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        naturalnumbers: Optional[Naturalnumbers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        rationals: Optional[Rationals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        reals: Optional[Reals] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        integers: Optional[Integers] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        infinity: Optional[Infinity] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        eulergamma: Optional[Eulergamma] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        pi: Optional[Pi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        false: Optional[FalseType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        true: Optional[TrueType] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        notanumber: Optional[Notanumber] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        imaginaryi: Optional[Imaginaryi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        exponentiale: Optional[Exponentiale] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maction: Optional["Maction"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mlongdiv: Optional[Mlongdiv] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstack: Optional[Mstack] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtable: Optional[Mtable] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mmultiscripts: Optional[Mmultiscripts] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munderover: Optional[Munderover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mover: Optional[Mover] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        munder: Optional[Munder] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msubsup: Optional[Msubsup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msup: Optional[Msup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msub: Optional[Msub] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        menclose: Optional[Menclose] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfenced: Optional[Mfenced] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mphantom: Optional[Mphantom] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mpadded: Optional[Mpadded] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        merror: Optional[Merror] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mstyle: Optional[Mstyle] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mroot: Optional[Mroot] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        msqrt: Optional[Msqrt] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mfrac: Optional[Mfrac] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mrow: Optional[Mrow] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        maligngroup: Optional[Maligngroup] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        malignmark: Optional[Malignmark] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        ms: Optional[Ms] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mspace: Optional[Mspace] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mtext: Optional[Mtext] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mo: Optional[Mo] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mn: Optional[Mn] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        mi: Optional[Mi] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        semantics: Optional["Maction.Semantics"] = field(
            default=None,
            metadata={
                "type": "Element",
            }
        )
        annotation: List[Annotation] = field(
            default_factory=list,
            metadata={
                "type": "Element",
            }
        )
        annotation_xml: List[AnnotationXml] = field(
            default_factory=list,
            metadata={
                "name": "annotation-xml",
                "type": "Element",
            }
        )
        id: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        xref: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        class_value: List[str] = field(
            default_factory=list,
            metadata={
                "name": "class",
                "type": "Attribute",
                "tokens": True,
            }
        )
        style: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        href: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other: Optional[object] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        other_attributes: Dict[str, str] = field(
            default_factory=dict,
            metadata={
                "type": "Attributes",
                "namespace": "##other",
            }
        )
        encoding: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        definition_url: Optional[str] = field(
            default=None,
            metadata={
                "name": "definitionURL",
                "type": "Attribute",
            }
        )
        cd: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )
        name: Optional[str] = field(
            default=None,
            metadata={
                "type": "Attribute",
            }
        )


@dataclass
class CnContent:
    class Meta:
        name = "cn.content"

    content: List[object] = field(
        default_factory=list,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
            "mixed": True,
            "choices": (
                {
                    "name": "mglyph",
                    "type": Mglyph,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "sep",
                    "type": Sep,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "maction",
                    "type": Maction,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mlongdiv",
                    "type": Mlongdiv,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mstack",
                    "type": Mstack,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mtable",
                    "type": Mtable,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mmultiscripts",
                    "type": Mmultiscripts,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "munderover",
                    "type": Munderover,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mover",
                    "type": Mover,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "munder",
                    "type": Munder,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msubsup",
                    "type": Msubsup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msup",
                    "type": Msup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msub",
                    "type": Msub,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "menclose",
                    "type": Menclose,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mfenced",
                    "type": Mfenced,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mphantom",
                    "type": Mphantom,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mpadded",
                    "type": Mpadded,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "merror",
                    "type": Merror,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mstyle",
                    "type": Mstyle,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mroot",
                    "type": Mroot,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "msqrt",
                    "type": Msqrt,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mfrac",
                    "type": Mfrac,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mrow",
                    "type": Mrow,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "maligngroup",
                    "type": Maligngroup,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "malignmark",
                    "type": Malignmark,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "ms",
                    "type": Ms,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mspace",
                    "type": Mspace,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mtext",
                    "type": Mtext,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mo",
                    "type": Mo,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mn",
                    "type": Mn,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
                {
                    "name": "mi",
                    "type": Mi,
                    "namespace": "http://www.w3.org/1998/Math/MathML",
                },
            ),
        }
    )


@dataclass
class Cn(CnContent):
    class Meta:
        name = "cn"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    encoding: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    definition_url: Optional[str] = field(
        default=None,
        metadata={
            "name": "definitionURL",
            "type": "Attribute",
        }
    )
    type: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    base: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
